==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ta-IN/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'இந்த மின்னஞ்சலுடன் ஒரு கணக்கு ஏற்கனவே உள்ளது.',
    'account_not_found'      => 'பயனர் பெயர் அல்லது கடவுச்சொல் தவறானது.',
    'account_not_activated'  => 'இந்த பயனர் கணக்கு செயல்படுத்தப்படவில்லை.',
    'account_suspended'      => 'இந்த பயனர் கணக்கு இடைநீக்கம் செய்யப்பட்டுள்ளது.',
    'account_banned'         => 'இந்த பயனர் கணக்கு தடைசெய்யப்பட்டுள்ளது.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'வெற்றிகரமாக உள்நுழைந்துள்ளீர்கள்.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'உங்களை உள்நுழைய முயற்சிக்கும்போது சிக்கல் ஏற்பட்டது, தயவுசெய்து மீண்டும் முயற்சிக்கவும்.',
        'success' => 'வெற்றிகரமாக உள்நுழைந்துள்ளீர்கள்.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'உங்கள் கணக்கை உருவாக்க முயற்சிக்கும்போது ஒரு சிக்கல் ஏற்பட்டது, மீண்டும் முயற்சிக்கவும்.',
        'success' => 'கணக்கு வெற்றிகரமாக உருவாக்கப்பட்டது.',
    ),

    'forgot-password' => array(
        'error'   => 'மீட்டமை கடவுச்சொல் குறியீட்டை பெற முயற்சிக்கும் போது சிக்கல் ஏற்பட்டது, மீண்டும் முயற்சிக்கவும்.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க முயற்சிக்கும் போது ஒரு சிக்கல் ஏற்பட்டது, மீண்டும் முயற்சிக்கவும்.',
        'success' => 'உங்கள் கடவுச்சொல் வெற்றிகரமாக மீட்டமைக்கப்பட்டது.',
    ),


);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ta-IN/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'இந்த மின்னஞ்சலுடன் ஒரு கணக்கு ஏற்கனவே உள்ளது.',
    'account_not_found'      => 'பயனர் பெயர் அல்லது கடவுச்சொல் தவறானது.',
    'account_not_activated'  => 'இந்த பயனர் கணக்கு செயல்படுத்தப்படவில்லை.',
    'account_suspended'      => 'இந்த பயனர் கணக்கு இடைநீக்கம் செய்யப்பட்டுள்ளது.',
    'account_banned'         => 'இந்த பயனர் கணக்கு தடைசெய்யப்பட்டுள்ளது.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'வெற்றிகரமாக உள்நுழைந்துள்ளீர்கள்.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'உங்களை உள்நுழைய முயற்சிக்கும்போது சிக்கல் ஏற்பட்டது, தயவுசெய்து மீண்டும் முயற்சிக்கவும்.',
        'success' => 'வெற்றிகரமாக உள்நுழைந்துள்ளீர்கள்.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'உங்கள் கணக்கை உருவாக்க முயற்சிக்கும்போது ஒரு சிக்கல் ஏற்பட்டது, மீண்டும் முயற்சிக்கவும்.',
        'success' => 'கணக்கு வெற்றிகரமாக உருவாக்கப்பட்டது.',
    ),

    'forgot-password' => array(
        'error'   => 'மீட்டமை கடவுச்சொல் குறியீட்டை பெற முயற்சிக்கும் போது சிக்கல் ஏற்பட்டது, மீண்டும் முயற்சிக்கவும்.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'உங்கள் கடவுச்சொல்லை மீட்டமைக்க முயற்சிக்கும் போது ஒரு சிக்கல் ஏற்பட்டது, மீண்டும் முயற்சிக்கவும்.',
        'success' => 'உங்கள் கடவுச்சொல் வெற்றிகரமாக மீட்டமைக்கப்பட்டது.',
    ),


);
